@@ -22,7 +22,6 @@ import collections
 import textwrap
 
 from googlecloudsdk.api_lib.compute.instances.ops_agents import ops_agents_policy as agent_policy
-from googlecloudsdk.calliope import exceptions
 
 
 class _PackageTemplates(
@@ -34,8 +33,8 @@ class _PackageTemplates(
 class _AgentTemplates(
     collections.namedtuple(
         '_AgentTemplates',
-        ('yum_package', 'apt_package', 'run_agent', 'repo_id', 'display_name',
-         'recipe_name', 'current_major_version'))):
+        ('yum_package', 'apt_package', 'zypper_package', 'run_agent', 'repo_id',
+         'display_name', 'recipe_name', 'current_major_version'))):
   pass
 
 
@@ -44,17 +43,26 @@ _AGENT_TEMPLATES = {
         _AgentTemplates(
             yum_package=_PackageTemplates(
                 repo={
-                    'all': 'google-cloud-logging-%s-x86_64-all',
-                    '1.x.x': 'google-cloud-logging-%s-x86_64-1'
+                    'all': 'google-cloud-logging-el%s-x86_64-all',
+                    '1.*.*': 'google-cloud-logging-el%s-x86_64-1'
                 },
                 install_with_version=textwrap.dedent("""\
                     sudo yum remove google-fluentd
                     sudo yum install -y 'google-fluentd%s'"""),
             ),
+            zypper_package=_PackageTemplates(
+                repo={
+                    'all': 'google-cloud-logging-sles%s-x86_64-all',
+                    '1.*.*': 'google-cloud-logging-sles%s-x86_64-1'
+                },
+                install_with_version=textwrap.dedent("""\
+                    sudo zypper remove google-fluentd
+                    sudo zypper install -y 'google-fluentd%s'"""),
+            ),
             apt_package=_PackageTemplates(
                 repo={
                     'all': 'google-cloud-logging-%s-all',
-                    '1.x.x': 'google-cloud-logging-%s-1'
+                    '1.*.*': 'google-cloud-logging-%s-1'
                 },
                 install_with_version=textwrap.dedent("""\
                     sudo apt-get remove google-fluentd
@@ -67,25 +75,35 @@ _AGENT_TEMPLATES = {
                     sleep 5m
                     %(install)s"""),
             recipe_name='set-google-fluentd-version',
-            current_major_version='1.x.x',
+            current_major_version='1.*.*',
         ),
     'metrics':
         _AgentTemplates(
             yum_package=_PackageTemplates(
                 repo={
-                    'all': 'google-cloud-monitoring-%s-x86_64-all',
-                    '5.x.x': 'google-cloud-monitoring-%s-x86_64-5',
-                    '6.x.x': 'google-cloud-monitoring-%s-x86_64-6'
+                    'all': 'google-cloud-monitoring-el%s-x86_64-all',
+                    '5.*.*': 'google-cloud-monitoring-el%s-x86_64-5',
+                    '6.*.*': 'google-cloud-monitoring-el%s-x86_64-6'
                 },
                 install_with_version=textwrap.dedent("""\
                     sudo yum remove stackdriver-agent
                     sudo yum install -y 'stackdriver-agent%s'"""),
             ),
+            zypper_package=_PackageTemplates(
+                repo={
+                    'all': 'google-cloud-monitoring-sles%s-x86_64-all',
+                    '5.*.*': 'google-cloud-monitoring-sles%s-x86_64-5',
+                    '6.*.*': 'google-cloud-monitoring-sles%s-x86_64-6'
+                },
+                install_with_version=textwrap.dedent("""\
+                    sudo zypper remove stackdriver-agent
+                    sudo zypper install -y 'stackdriver-agent%s'"""),
+            ),
             apt_package=_PackageTemplates(
                 repo={
                     'all': 'google-cloud-monitoring-%s-all',
-                    '5.x.x': 'google-cloud-monitoring-%s-5',
-                    '6.x.x': 'google-cloud-monitoring-%s-6'
+                    '5.*.*': 'google-cloud-monitoring-%s-5',
+                    '6.*.*': 'google-cloud-monitoring-%s-6'
                 },
                 install_with_version=textwrap.dedent("""\
                     sudo apt-get remove stackdriver-agent
@@ -98,18 +116,26 @@ _AGENT_TEMPLATES = {
                     sleep 5m
                     %(install)s"""),
             recipe_name='set-stackdriver-agent-version',
-            current_major_version='6.x.x',
+            current_major_version='6.*.*',
         ),
 }
 
-_DEBIAN_REPO_CODENAMES = {
+_APT_CODENAMES = {
     '8': 'jessie',
     '9': 'stretch',
     '10': 'buster',
+    '16.04': 'xenial',
+    '18.04': 'bionic',
+    '19.10': 'eoan',
+    '20.04': 'focal',
 }
 
+_SUSE_OS = ('sles-sap', 'sles')
 
-def _CreatePackages(messages, agents):
+_APT_OS = ('debian', 'ubuntu')
+
+
+def _CreatePackages(messages, agents, os_type):
   """Create OS Agent guest policy packages from Ops Agent policy agent field."""
   packages = []
   for agent in agents or []:
@@ -120,17 +146,21 @@ def _CreatePackages(messages, agents):
       packages.append(
           _CreatePackage(messages, 'google-fluentd-catch-all-config',
                          agent.package_state, agent.enable_autoupgrade))
-      packages.append(
-          _CreatePackage(messages, 'google-fluentd-start-service',
-                         agent.package_state, agent.enable_autoupgrade))
+      # apt os will start the service automatically without the start-service.
+      if os_type.short_name not in _APT_OS:
+        packages.append(
+            _CreatePackage(messages, 'google-fluentd-start-service',
+                           agent.package_state, agent.enable_autoupgrade))
 
     if agent.type is agent_policy.OpsAgentPolicy.Agent.Type.METRICS:
       packages.append(
           _CreatePackage(messages, 'stackdriver-agent', agent.package_state,
                          agent.enable_autoupgrade))
-      packages.append(
-          _CreatePackage(messages, 'stackdriver-agent-start-service',
-                         agent.package_state, agent.enable_autoupgrade))
+      # apt os will start the service automatically without the start-service.
+      if os_type.short_name not in _APT_OS:
+        packages.append(
+            _CreatePackage(messages, 'stackdriver-agent-start-service',
+                           agent.package_state, agent.enable_autoupgrade))
   return packages
 
 
@@ -171,32 +201,61 @@ def _CreatePackageRepositories(messages, os_type, agents):
     package repos in guest policy.
   """
   package_repos = None
-  if os_type.short_name == 'debian':
-    version = _DEBIAN_REPO_CODENAMES.get(os_type.version)
-    if version is None:
-      raise exceptions.BadArgumentException(
-          'os_type.version',
-          'Version: %s in OS %s is either not correct or not being supported.' %
-          (os_type.version, os_type.short_name))
-    package_repos = _CreateAptPkgRepos(messages, version, agents)
+  if os_type.short_name in _APT_OS:
+    package_repos = _CreateAptPkgRepos(
+        messages, _APT_CODENAMES.get(os_type.version), agents)
   elif os_type.short_name in {'rhel', 'centos'}:
-    # TODO(b/158695873): For cases like [rhel, 7.8] and [centos, 7].
-    # I shall remove this code once os config starts supporting wildcard.
     version = os_type.version.split('.')[0]
-    package_repos = _CreateYumPkgRepos(messages, 'el%s' % version, agents)
-  else:
-    # TODO(b/160098692): Implement support for SLES and UBUNTU.
-    raise exceptions.BadArgumentException(
-        'os_type.short_name',
-        'OS: %s is not being supported.' % os_type.short_name)
+    version = version.split('*')[0]
+    package_repos = _CreateYumPkgRepos(messages, version, agents)
+  elif os_type.short_name in _SUSE_OS:
+    version = os_type.version.split('.')[0]
+    version = version.split('*')[0]
+    package_repos = _CreateZypperPkgRepos(messages, version, agents)
   return package_repos
 
 
+def _CreateZypperPkgRepos(messages, repo_distro, agents):
+  zypper_pkg_repos = []
+  for agent in agents:
+    template = _AGENT_TEMPLATES[agent.type]
+    repo_key = agent.version if '*.*' in agent.version else 'all'
+    repo_name = template.zypper_package.repo[repo_key] % repo_distro
+    zypper_pkg_repos.append(
+        _CreateZypperPkgRepo(messages, template.repo_id, template.display_name,
+                             repo_name))
+  return zypper_pkg_repos
+
+
+def _CreateZypperPkgRepo(messages, repo_id, display_name, repo_name):
+  """Create a zypper repo in guest policy.
+
+  Args:
+    messages: os config guest policy api messages.
+    repo_id: 'google-cloud-logging' or 'google-cloud-monitoring'.
+    display_name: 'Google Cloud Logging Agent Repository' or 'Google Cloud
+      Monitoring Agent Repository'.
+    repo_name: repository name.
+
+  Returns:
+    zypper repos in guest policy.
+  """
+  return messages.PackageRepository(
+      zypper=messages.ZypperRepository(
+          id=repo_id,
+          displayName=display_name,
+          baseUrl='https://packages.cloud.google.com/yum/repos/%s' % repo_name,
+          gpgKeys=[
+              'https://packages.cloud.google.com/yum/doc/yum-key.gpg',
+              'https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg'
+          ]))
+
+
 def _CreateYumPkgRepos(messages, repo_distro, agents):
   yum_pkg_repos = []
   for agent in agents:
     template = _AGENT_TEMPLATES[agent.type]
-    repo_key = agent.version if 'x.x' in agent.version else 'all'
+    repo_key = agent.version if '*.*' in agent.version else 'all'
     repo_name = template.yum_package.repo[repo_key] % repo_distro
     yum_pkg_repos.append(
         _CreateYumPkgRepo(messages, template.repo_id, template.display_name,
@@ -231,7 +290,7 @@ def _CreateYumPkgRepo(messages, repo_id, display_name, repo_name):
 def _CreateAptPkgRepos(messages, repo_distro, agents):
   apt_pkg_repos = []
   for agent in agents or []:
-    repo_key = agent.version if 'x.x' in agent.version else 'all'
+    repo_key = agent.version if '*.*' in agent.version else 'all'
     repo_name = _AGENT_TEMPLATES[agent.type].apt_package.repo.get(
         repo_key) % repo_distro
     apt_pkg_repos.append(_CreateAptPkgRepo(messages, repo_name))
@@ -299,13 +358,21 @@ def _CreateAssignment(messages, assignment_group_labels, assignment_os_types,
       osTypes=_CreateOstypes(messages, assignment_os_types))
 
 
-def _CreateRecipes(messages, agents, os_type):
+def _GetRecipeVersion(prev_recipes, recipe_name):
+  for recipe in prev_recipes or []:
+    if recipe.name == recipe_name:
+      return str(int(recipe.version)+1)
+  return '0'
+
+
+def _CreateRecipes(messages, agents, os_type, prev_recipes):
   """Create recipes in guest policy.
 
   Args:
     messages: os config guest policy api messages.
     agents: ops agent policy agents.
-    os_type: ops agent policy os_type
+    os_type: ops agent policy os_type.
+    prev_recipes: a list of SoftwareRecipe.
 
   Returns:
     Recipes in guest policy
@@ -314,15 +381,21 @@ def _CreateRecipes(messages, agents, os_type):
   for agent in agents or []:
     recipes.append(
         _CreateRecipe(messages, _CreateStepInScript(messages, agent, os_type),
-                      _AGENT_TEMPLATES[agent.type].recipe_name))
+                      _AGENT_TEMPLATES[agent.type].recipe_name,
+                      _GetRecipeVersion(prev_recipes,
+                                        _AGENT_TEMPLATES[agent.type].recipe_name
+                                        )
+                      )
+        )
   return recipes
 
 
-def _CreateRecipe(messages, run_script, recipe_name):
+def _CreateRecipe(messages, run_script, recipe_name, version):
   return messages.SoftwareRecipe(
       desiredState=messages.SoftwareRecipe.DesiredStateValueValuesEnum.UPDATED,
       installSteps=[run_script],
-      name=recipe_name)
+      name=recipe_name,
+      version=version)
 
 
 def _CreateStepInScript(messages, agent, os_type):
@@ -343,22 +416,30 @@ def _CreateStepInScript(messages, agent, os_type):
     os_version = os_type.version.split('.')[0]
     if agent.version == 'latest':
       agent_version = ''
-    elif 'x.x' in agent.version:
-      agent_version = '-%s' % agent.version.replace('x.x', '*')
+    elif '*.*' in agent.version:
+      agent_version = '-%s' % agent.version.replace('*.*', '*')
     else:
       agent_version = '-%s.el%s' % (agent.version, os_version)
-
     run_script = _AGENT_TEMPLATES[
         agent.type].yum_package.install_with_version % agent_version
-  if os_type.short_name == 'debian':
+  if os_type.short_name in _APT_OS:
     if agent.version == 'latest':
       agent_version = ''
-    elif 'x.x' in agent.version:
-      agent_version = '=%s' % agent.version.replace('x.x', '*')
+    elif '*.*' in agent.version:
+      agent_version = '=%s' % agent.version.replace('*.*', '*')
     else:
       agent_version = '=%s' % agent.version
     run_script = _AGENT_TEMPLATES[
         agent.type].apt_package.install_with_version % agent_version
+  if os_type.short_name in _SUSE_OS:
+    if agent.version == 'latest':
+      agent_version = ''
+    elif '*.*' in agent.version:
+      agent_version = '<%s' % str(int(agent.version.split('.')[0])+1)+'.*'
+    else:
+      agent_version = '=%s' % agent.version
+    run_script = _AGENT_TEMPLATES[
+        agent.type].zypper_package.install_with_version % agent_version
   step.scriptRun.script = _AGENT_TEMPLATES[agent.type].run_agent % {
       'install': run_script
   }
@@ -389,7 +470,8 @@ def _SetAgentVersion(agents):
       agent.version = _AGENT_TEMPLATES[agent.type].current_major_version
 
 
-def ConvertOpsAgentPolicyToGuestPolicy(messages, ops_agents_policy):
+def ConvertOpsAgentPolicyToGuestPolicy(messages, ops_agents_policy,
+                                       prev_recipes=None):
   """Converts Ops Agent policy to OS Config guest policy."""
   ops_agents_policy_assignment = ops_agents_policy.assignment
   _SetAgentVersion(ops_agents_policy.agents)
@@ -402,11 +484,13 @@ def ConvertOpsAgentPolicyToGuestPolicy(messages, ops_agents_policy):
                                    ops_agents_policy_assignment.os_types,
                                    ops_agents_policy_assignment.zones,
                                    ops_agents_policy_assignment.instances),
-      packages=_CreatePackages(messages, ops_agents_policy.agents),
+      packages=_CreatePackages(messages, ops_agents_policy.agents,
+                               ops_agents_policy_assignment.os_types[0]),
       packageRepositories=_CreatePackageRepositories(
           messages, ops_agents_policy_assignment.os_types[0],
           ops_agents_policy.agents),
       recipes=_CreateRecipes(messages, ops_agents_policy.agents,
-                             ops_agents_policy.assignment.os_types[0]))
+                             ops_agents_policy.assignment.os_types[0],
+                             prev_recipes))
 
   return guest_policy
