@@ -284,6 +284,7 @@ def AddImageArgs(parser, enable_snapshots=False):
         will be created from. You can provide this as a full URL
         to the snapshot or just the snapshot name. For example, the following
         are valid values:
+
           * https://compute.googleapis.com/compute/v1/projects/myproject/global/snapshots/snapshot
           * snapshot
         """)
@@ -592,13 +593,14 @@ def AddCreateDiskArgs(parser,
       image family references will be resolved. It is best practice to define
       image-project. A full list of available projects can be generated by
       running `gcloud projects list`.
-          * If specifying one of our public images, image-project must be
-            provided.
-          * If there are several of the same image-family value in multiple
-            projects, image-project must be specified to clarify the image to be
-            used.
-          * If not specified and either image or image-family is provided, the
-            current default project is used.
+
+        * If specifying one of our public images, image-project must be
+          provided.
+        * If there are several of the same image-family value in multiple
+          projects, image-project must be specified to clarify the image to be
+          used.
+        * If not specified and either image or image-family is provided, the
+          current default project is used.
 
       *size*::: The size of the disk. The value must be a whole number
       followed by a size unit of ``KB'' for kilobyte, ``MB'' for
@@ -613,7 +615,7 @@ def AddCreateDiskArgs(parser,
 
       *device-name*::: {disk_device}
 
-      *auto-delete*::: If ``yes'',  this persistent disk will be
+      *auto-delete*::: If ``yes'', this persistent disk will be
       automatically deleted when the instance is deleted. However,
       if the disk is later detached from the instance, this option
       won't apply. The default value for this is ``yes''.
@@ -631,24 +633,32 @@ def AddCreateDiskArgs(parser,
     disk_help += """
       *kms-key*::: Fully qualified Cloud KMS cryptokey name that will
       protect the {resource}.
+
       This can either be the fully qualified path or the name.
+
       The fully qualified Cloud KMS cryptokey name format is:
       ``projects/<kms-project>/locations/<kms-location>/keyRings/<kms-keyring>/
       cryptoKeys/<key-name>''.
+
       If the value is not fully qualified then kms-location, kms-keyring, and
       optionally kms-project are required.
+
       See {kms_help} for more details.
 
       *kms-project*::: Project that contains the Cloud KMS cryptokey that will
       protect the {resource}.
+
       If the project is not specified then the project where the {resource} is
       being created will be used.
+
       If this flag is set then key-location, kms-keyring, and kms-key
       are required.
+
       See {kms_help} for more details.
 
       *kms-location*::: Location of the Cloud KMS cryptokey to be used for
       protecting the {resource}.
+
       All Cloud KMS cryptokeys are reside in a 'location'.
       To get a list of possible locations run 'gcloud kms locations list'.
       If this flag is set then kms-keyring and kms-key are required.
@@ -656,7 +666,9 @@ def AddCreateDiskArgs(parser,
 
       *kms-keyring*::: The keyring which contains the Cloud KMS cryptokey that
       will protect the {resource}.
+
       If this flag is set then kms-location and kms-key are required.
+
       See {kms_help} for more details.
       """.format(
           resource='disk', kms_help=kms_utils.KMS_HELP_URL)
@@ -690,6 +702,7 @@ def AddCreateDiskArgs(parser,
       create the disk. You can provide this as a full URL
       to the snapshot or just the snapshot name. For example, the following
       are valid values:
+
         * https://compute.googleapis.com/compute/v1/projects/myproject/global/snapshots/snapshot
         * snapshot
       """
@@ -699,8 +712,10 @@ def AddCreateDiskArgs(parser,
     disk_help += """
       *disk-resource-policy*::: Resource policy that will be applied to created
       disk. You can provide full or partial URL. For more details see
+
         * https://cloud.google.com/sdk/gcloud/reference/beta/compute/resource-policies/
         * https://cloud.google.com/compute/docs/disks/scheduled-snapshots
+
       """
     spec['disk-resource-policy'] = arg_parsers.ArgList(max_length=1)
 
@@ -710,8 +725,10 @@ def AddCreateDiskArgs(parser,
       that will be used to create the disk. This can be provided as a full URL
       to the snapshot or just the snapshot name. For example, the following
       are valid values:
-       * https://www.googleapis.com/compute/v1/projects/myproject/global/snapshots/snapshot
-       * snapshot
+
+        * https://www.googleapis.com/compute/v1/projects/myproject/global/snapshots/snapshot
+        * snapshot
+
       Must be specified with `source-snapshot-csek-key-file`.
 
       *source-snapshot-csek-key-file::: Path to a Customer-Supplied Encryption
@@ -730,7 +747,7 @@ def AddCreateDiskArgs(parser,
       flags are omitted a blank disk will be created. Must be specified with
       `image-csek-key-file`.
 
-      *image-csek-key-file::: Path to a Customer-Supplied Encryption Key (CSEK)
+      *image-csek-key-file*::: Path to a Customer-Supplied Encryption Key (CSEK)
       key file for the image. Must be specified with `image-csek-required`.
     """
     spec['image-csek-key-file'] = str
