@@ -193,6 +193,11 @@ class CreateAlpha(CreateBeta):
   https://cloud.google.com/ml-engine/docs/how-tos/managing-models-jobs
   """
 
+  @staticmethod
+  def Args(parser):
+    CreateBeta.Args(parser)
+    flags.AddContainerFlags(parser)
+
   def Run(self, args):
     with endpoint_util.MlEndpointOverrides(region=args.region):
       client = versions_api.VersionsClient()
@@ -221,4 +226,11 @@ class CreateAlpha(CreateBeta):
           explanation_method=args.explanation_method,
           num_integral_steps=args.num_integral_steps,
           num_paths=args.num_paths,
+          image=args.image,
+          command=args.command,
+          container_args=args.args,
+          env_vars=args.env_vars,
+          ports=args.ports,
+          predict_route=args.predict_route,
+          health_route=args.health_route,
           containers_hidden=False)
