@@ -33,7 +33,8 @@ class ConfigureDockerError(exceptions.Error):
   """General command error class."""
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 class ConfigureDocker(base.Command):
   # pylint: disable=line-too-long
   r"""Register `gcloud` as a Docker credential helper.
@@ -54,87 +55,6 @@ class ConfigureDocker(base.Command):
   """
   # pylint: enable=line-too-long
 
-  def DockerCredentialGcloudExists(self):
-    return file_utils.SearchForExecutableOnPath(
-        'docker-credential-gcloud') or file_utils.SearchForExecutableOnPath(
-            'docker-credential-gcloud.cmd')
-
-  def DockerExists(self):
-    return file_utils.SearchForExecutableOnPath(
-        'docker') or file_utils.SearchForExecutableOnPath('docker.exe')
-
-  def Run(self, args):
-    """Run the configure-docker command."""
-    if not self.DockerCredentialGcloudExists():
-      log.warning('`docker-credential-gcloud` not in system PATH.\n'
-                  'gcloud\'s Docker credential helper can be configured but '
-                  'it will not work until this is corrected.')
-
-    current_config = cred_utils.Configuration.ReadFromDisk()
-
-    if self.DockerExists():
-      if not current_config.SupportsRegistryHelpers():
-        raise ConfigureDockerError(
-            'Invalid Docker version: The version of your Docker client is '
-            '[{}]; version [{}] or higher is required to support Docker '
-            'credential helpers.'.format(
-                current_config.DockerVersion(),
-                cred_utils.MIN_DOCKER_CONFIG_HELPER_VERSION))
-    else:
-      log.warning(
-          '`docker` not in system PATH.\n'
-          '`docker` and `docker-credential-gcloud` need to be in the same PATH '
-          'in order to work correctly together.\n'
-          'gcloud\'s Docker credential helper can be configured but '
-          'it will not work until this is corrected.')
-
-    current_helpers = current_config.GetRegisteredCredentialHelpers()
-    new_helpers = cred_utils.GetGcloudCredentialHelperConfig()
-
-    if new_helpers == current_helpers:
-      log.status.Print('gcloud credential helpers '
-                       'already registered correctly.')
-      return
-
-    if current_helpers:
-      log.warning(
-          'Your config file at [{0}] contains these credential helper '
-          'entries:\n\n{1}\nThese will be overwritten.'.format(
-              current_config.path, json.dumps(current_helpers, indent=2)))
-
-    console_io.PromptContinue(
-        message='The following settings will be added to your Docker '
-        'config file located at [{0}]:\n {1}'.format(
-            current_config.path,
-            json.dumps(new_helpers, indent=2)),
-        cancel_on_no=True)
-
-    current_config.RegisterCredentialHelpers()
-    log.status.Print('Docker configuration file updated.')
-
-
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA,
-                    base.ReleaseTrack.BETA)
-class ConfigureDockerBeta(base.Command):
-  # pylint: disable=line-too-long
-  r"""Register `gcloud` as a Docker credential helper.
-
-  {command} adds the Docker `credHelper` entry to Docker's configuration file,
-  or creates the file if it doesn't exist. This will register `gcloud` as the
-  credential helper for all Google-supported Docker registries. If the Docker
-  configuration already contains a `credHelper` entry, it will be overwritten.
-
-  Note, `docker` and `gcloud` need to be on the same system `PATH` to work
-  correctly.
-
-  For more details on Docker credential helpers, see
-  [](https://docs.docker.com/engine/reference/commandline/login/#credential-helpers).
-
-  For more details on the Google Container Registry's Docker credential helper,
-  see [](https://github.com/GoogleCloudPlatform/docker-credential-gcr).
-  """
-  # pylint: enable=line-too-long
-
   def DockerCredentialGcloudExists(self):
     return file_utils.SearchForExecutableOnPath(
         'docker-credential-gcloud') or file_utils.SearchForExecutableOnPath(
