@@ -38,7 +38,7 @@ class Describe(base.DescribeCommand):
   """Describe a Google Compute Engine network endpoint group."""
 
   detailed_help = DETAILED_HELP
-  support_global_scope = False
+  support_global_scope = True
   support_regional_scope = False
 
   @classmethod
@@ -80,15 +80,8 @@ class Describe(base.DescribeCommand):
     return client.MakeRequests([(service, 'Get', request)])[0]
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
-class DescribeBeta(Describe):
-  """Describe a Google Compute Engine network endpoint group."""
-
-  support_global_scope = True
-
-
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class DescribeAlpha(DescribeBeta):
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
+class DescribeAlphaBeta(Describe):
   """Describe a Google Compute Engine network endpoint group."""
 
   support_regional_scope = True
