@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,11 +15,14 @@
 """List keyrings within a location."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from apitools.base.py import list_pager
 from googlecloudsdk.api_lib.cloudkms import base as cloudkms_base
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.kms import flags
+from googlecloudsdk.command_lib.kms import resource_args
 
 
 class List(base.ListCommand):
@@ -32,19 +35,25 @@ class List(base.ListCommand):
   The following command lists a maximum of five keyrings in the location
   `global`:
 
-    $ {command} --location global --limit=5
+    $ {command} --location=global --limit=5
   """
 
   @staticmethod
   def Args(parser):
-    flags.AddLocationFlag(parser, 'keyring')
+    if List.ReleaseTrack() == base.ReleaseTrack.GA:
+      flags.AddLocationFlag(parser, 'keyring')
+    else:
+      resource_args.AddKmsLocationResourceArgForKMS(parser, True, '--location')
+
     parser.display_info.AddFormat('table(name)')
 
   def Run(self, args):
     client = cloudkms_base.GetClientInstance()
     messages = cloudkms_base.GetMessagesModule()
-
-    location_ref = flags.ParseLocationName(args)
+    if List.ReleaseTrack() == base.ReleaseTrack.GA:
+      location_ref = flags.ParseLocationName(args)
+    else:
+      location_ref = args.CONCEPTS.location.Parse()
 
     request = messages.CloudkmsProjectsLocationsKeyRingsListRequest(
         parent=location_ref.RelativeName())
