@@ -77,7 +77,8 @@ LOGGER = logging.getLogger('integration-test')
 # TODO: Replace tests which looks for test_api == ApiSelector.(XML|JSON) with
 # these decorators.
 def SkipForXML(reason):
-  if not USING_JSON_API:
+  """Skips the test if running S3 tests, or if prefer_api isn't set to json."""
+  if not USING_JSON_API or RUN_S3_TESTS:
     return unittest.skip(reason)
   else:
     return lambda func: func
@@ -137,7 +138,7 @@ class GsUtilIntegrationTestCase(base.GsUtilTestCase):
                                DiscardMessagesQueue(), 'gs')
     self.xml_api = BotoTranslation(BucketStorageUri, logging.getLogger(),
                                    DiscardMessagesQueue, self.default_provider)
-    self.kms_api = KmsApi()
+    self.kms_api = KmsApi(logging.getLogger())
 
     self.multiregional_buckets = util.USE_MULTIREGIONAL_BUCKETS
 
@@ -518,7 +519,8 @@ class GsUtilIntegrationTestCase(base.GsUtilTestCase):
                    versioning_enabled=False,
                    bucket_policy_only=False,
                    bucket_name_prefix='',
-                   bucket_name_suffix=''):
+                   bucket_name_suffix='',
+                   location=None):
     """Creates a test bucket.
 
     The bucket and all of its contents will be deleted after the test.
@@ -538,6 +540,7 @@ class GsUtilIntegrationTestCase(base.GsUtilTestCase):
           bucketPolicyOnly attribute to True.
       bucket_name_prefix: Unicode string to be prepended to bucket_name
       bucket_name_suffix: Unicode string to be appended to bucket_name
+      location: The location/region in which the bucket should be created.
 
     Returns:
       StorageUri for the created bucket.
@@ -546,13 +549,15 @@ class GsUtilIntegrationTestCase(base.GsUtilTestCase):
       provider = self.default_provider
 
     # Location is controlled by the -b test flag.
-    if self.multiregional_buckets or provider == 's3':
-      location = None
-    else:
-      # We default to the "us-central1" location for regional buckets, but allow
-      # overriding this value in the Boto config.
-      location = boto.config.get('GSUtil', 'test_cmd_regional_bucket_location',
-                                 'us-central1')
+    if location is None:
+      if self.multiregional_buckets or provider == 's3':
+        location = None
+      else:
+        # We default to the "us-central1" location for regional buckets,
+        # but allow overriding this value in the Boto config.
+        location = boto.config.get('GSUtil',
+                                   'test_cmd_regional_bucket_location',
+                                   'us-central1')
 
     bucket_name_prefix = six.ensure_text(bucket_name_prefix)
     bucket_name_suffix = six.ensure_text(bucket_name_suffix)
@@ -975,13 +980,15 @@ class GsUtilIntegrationTestCase(base.GsUtilTestCase):
 
     # executing command - the setsid allows us to kill the process group below
     # if the execution times out.  With python 2.7, there's no other way to
-    # stop the execution (p.kill() doesn't work).
+    # stop the execution (p.kill() doesn't work).  Since setsid is not available
+    # on Windows, we just deal with the occasional timeouts on Windows.
+    preexec_fn = os.setsid if hasattr(os, 'setsid') else None
     p = subprocess.Popen(cmd,
                          stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE,
                          stdin=subprocess.PIPE,
                          env=envstr,
-                         preexec_fn=os.setsid)
+                         preexec_fn=preexec_fn)
     comm_kwargs = {'input': stdin}
 
     def Kill():
@@ -1216,7 +1223,7 @@ class GsUtilIntegrationTestCase(base.GsUtilTestCase):
 
 class KmsTestingResources(object):
   """Constants for KMS resource names to be used in integration testing."""
-  KEYRING_LOCATION = 'global'
+  KEYRING_LOCATION = 'us-central1'
   # Since KeyRings and their child resources cannot be deleted, we minimize the
   # number of resources created by using a hard-coded keyRing name.
   KEYRING_NAME = 'keyring-for-gsutil-integration-tests'
